@@ -46,6 +46,26 @@ if [ "$app" = "sso" ]; then
         read session leftover
     done
 
+    sync=0
+    while [ $sync -lt 1 -o $sync -gt 2 ]; do
+        if [ $LANG = ja_JP.UTF-8 ]; then
+            printf "パスワードの同期 [1.する|2.しない]: "
+        else
+            printf "Password synchronization [1.Yes|2.No]: "
+        fi
+        read sync leftover
+    done
+
+    random=0
+    while [ $random -lt 1 -o $random -gt 2 ]; do
+        if [ $LANG = ja_JP.UTF-8 ]; then
+            printf "アクセス制限 [1.する|2.しない]: "
+        else
+            printf "Access restriction [1.Yes|2.no]: "
+        fi
+        read random leftover
+    done
+
     entityid=`echo $url | sed 's#[^/]*$##'`
     rurl=`echo $url | sed 's#/[^/]*$##'`
     path=`echo $rurl | sed 's#^https*://[^/]*/##'`
@@ -57,6 +77,12 @@ if [ "$app" = "sso" ]; then
 
     appname=`echo $path | sed 's#^\([^/]*\)/*.*$#\1#'`
 
+    if [ $sync -eq 1 -o $random -eq 1 ]; then
+        sync="on"
+    else
+        sync="0"
+    fi
+
     sed s#\'path#\'$path# ./conf/config.php | sed s#https://slink.secioss.com#$idpurl/$tenant# | sed s/SESSIONNAME/$session/ > /tmp/config.php
     mv /tmp/config.php /usr/share/simplesamlphp/config/config.php
 
@@ -69,6 +95,12 @@ if [ "$app" = "sso" ]; then
     sed "s#[^ ]*/saml#/$path/saml#" /etc/httpd/conf.d/simplesamlphp.conf > /tmp/simplesamlphp.conf
     mv /tmp/simplesamlphp.conf /etc/httpd/conf.d/simplesamlphp.conf
 
+    sed "s/sync = \".*\"/sync = \"$sync\"/" ./conf/config.ini > /tmp/config.ini
+    if [ "$random" -eq 1 ]; then
+        echo "encryptpwdattr = \"seciossrandompassword\"" >> /tmp/config.ini
+    fi
+    mv /tmp/config.ini /var/www/conf/config.ini
+
     sed s#path#$path# ./conf/autologin.conf > /tmp/autologin.conf
     mv /tmp/autologin.conf /etc/httpd/conf.d/autologin.conf
 
@@ -173,16 +205,18 @@ elif [ "$app" = "idm" ]; then
             sed "s/ *<!-- attribute//" /tmp/lism-sp.conf | sed "s/ *attribute -->//" | sed s/ATTRIBUTE/$attribute/ > /tmp/lism-sp2.conf
             mv /tmp/lism-sp2.conf /tmp/lism-sp.conf
         fi
-        mv /tmp/lism-sp.conf /opt/secioss/etc/lism-sp.conf
-        sed "s/seciossAllowedService=[^)]*/seciossAllowedService=$service-$tenant/" /opt/secioss/etc/lism.conf | sed "s/<constant>.*<\/constant>/<constant>$service-$tenant<\/constant>/" > /tmp/lism.conf
-        mv /tmp/lism.conf /opt/secioss/etc/lism.conf
+        cp /tmp/lism-sp.conf /opt/secioss/etc/lism-sp.conf
+        rm /tmp/lism-sp.conf
+        sed "s/seciossAllowedService=[^)]*/seciossAllowedService=$service-$tenant/" /opt/secioss/etc/lism.conf | sed "s/seciossAllowedService;x-perm-group=[^)]*/seciossAllowedService;x-perm-group=$service-$tenant/" | sed "s/<constant>.*<\/constant>/<constant>$service-$tenant<\/constant>/" > /tmp/lism.conf
+        cp /tmp/lism.conf /opt/secioss/etc/lism.conf
+        rm /tmp/lism.conf
 
         sed s#/opt/secioss/etc/[^\']*#/opt/secioss/etc/lism.conf# /var/www/html/lism/config.php > /tmp/config.php
         mv /tmp/config.php /var/www/html/lism/config.php
     else
-        sed s/uid%1%2@[^\"]*/uid%1%2@$tenant/ /opt/secioss/etc/lism-idp.conf | sed "s/<basedn>o=[^,]*/<basedn>o=$tenant/" | sed "s/<binddn>uid=[^,]*,ou=People,o=[^,]*/<binddn>$admin@$tenant,ou=People,o=$tenant/" | sed "s/<bindpw>[^<]*/<bindpw>$password/" | sed "s/!(uid=[^)]*/!(uid=$admin/" | sed s#https://slink.secioss.com#$idmurl# > /tmp/lism-idp.conf
-        mv /tmp/lism-idp.conf /opt/secioss/etc/lism-idp.conf
-
+        sed s/uid%1%2@[^\"]*/uid%1%2@$tenant/ /opt/secioss/etc/lism-idp.conf | sed "s/<basedn>o=[^,]*/<basedn>o=$tenant/" | sed "s/<binddn>uid=[^,]*,ou=People,o=[^,]*/<binddn>uid=$admin@$tenant,ou=People,o=$tenant/" | sed "s/<bindpw>[^<]*/<bindpw>$password/" | sed "s/!(uid=[^)]*/!(uid=$admin/" | sed s#https://slink.secioss.com#$idmurl# > /tmp/lism-idp.conf
+        cp /tmp/lism-idp.conf /opt/secioss/etc/lism-idp.conf
+        rm /tmp/lism-idp.conf
         sed s#/opt/secioss/etc/[^\']*#/opt/secioss/etc/lism-idp.conf# /var/www/html/lism/config.php > /tmp/config.php
         mv /tmp/config.php /var/www/html/lism/config.php
     fi
