@@ -40,6 +40,14 @@ foreach ($lismxml->data as $v)
         {
             if ((string)$vv->attributes()->name == 'User')
             {
+                $id = (string)$vv->id[0]->column;
+                if ($id) {
+                    $editlist[] = array("checked" => false,
+                            "master" => 'primary key',
+                            "field"  => $id
+                    );
+                }
+
                 foreach ($vv->attr as $vvv)
                 {
                     $master = (string)$vvv->attributes()->name;
