@@ -578,7 +578,7 @@ sub log
     $p{'message'} = uc($p{'level'}).' ['.ref($self).'] '.$p{'message'};
 
     if ($^O ne 'MSWin32') {
-        openlog('LISM', 'pid', 'local4');
+        openlog('LISM', 'pid', $self->{lism}->{_config}->{syslogfacility});
         setlogmask(Sys::Syslog::LOG_UPTO(Sys::Syslog::xlate($conf->{sysloglevel})));
         syslog($p{'level'}, $p{'message'});
         closelog();
@@ -833,11 +833,11 @@ sub _checkConfig
 
     # connection
     if (!defined($conf->{connection}[0]->{retry})
-        || $conf->{connection}[0]->{retry}[0] !~ /[0-9]*/) {
+        || $conf->{connection}[0]->{retry}[0] !~ /^[0-9]+$/) {
         $conf->{connection}[0]->{retry}[0] = 0;
     }
     if (!defined($conf->{connection}[0]->{interval})
-        || $conf->{connection}[0]->{interval}[0] !~ /[0-9]*/) {
+        || $conf->{connection}[0]->{interval}[0] !~ /^[0-9]+$/) {
         $conf->{connection}[0]->{interval}[0] = 10;
     }
 
@@ -1594,6 +1594,32 @@ sub _writeUpdateLog
     return 0;
 }
 
+sub random
+{
+    my $self = shift;
+    my ($len) = @_;
+    my $string;
+
+    my @chars;
+    push(@chars, ('a'..'z'), ('A'..'Z',), (0..9));
+
+    my ($sec, $microsec) = gettimeofday();
+    srand($microsec);
+
+    $string = '';
+
+    for (my $i = 0; $i < 10; $i++) {
+        for (my $j = 0; $j < $len; $j++) {
+            $string .= $chars[int(rand() * @chars)];
+        }
+        if ($string =~ /[a-zA-Z]/ && $string =~ /[0-9]/) {
+            last;
+        }
+    }
+
+    return $string;
+}
+
 =head1 SEE ALSO
 
 L<LISM>
