@@ -6,6 +6,13 @@ if (file_exists("../conf/menu.php")) {
     require_once("../conf/menu.php");
 }
 
+if (strtoupper(substr(PHP_OS, 0, 3)) !== 'WIN') {
+    $log = &Log::singleton('syslog', LOG_LOCAL5, $logid);
+} else {
+    $opts = array('locking' => true, 'timeFormat' => '%Y/%m/%d %H:%M:%S');
+    $log = &Log::singleton('file', '/secioss/var/log/auth.log', $logid, $opts);
+}
+
 if (isset($_SESSION['lang']) && $_SESSION['lang']) {
     $lang = $_SESSION['lang'];
 }
